import { deepMerge } from '@empathyco/x-deep-merge';
/**
 * Combines the given {@link Mapper | mappers} into a single {@link Mapper | mapper function}.
 *
 * @param mappers - The {@link Mapper | mapper functions} to combine.
 * @returns The combined {@link Mapper | mapper function}.
 *
 * @public
 */
export function combineMappers(...mappers) {
    return (from, context) => mappers.reduce((value, mapper) => {
        const mappedValue = mapper(from, context);
        context.mappedValue = deepMerge(value, mappedValue);
        return value;
    }, {});
}
//# sourceMappingURL=combine-mappers.js.map